/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann           *
 *     																	   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef UCQFONTBAR_H_
#define UCQFONTBAR_H_
#include <QToolBar>
#include <QFontComboBox>
#include <QComboBox>
#include <QStringList>
#include <QAction>
#include <QApplication>

/**
 * \class UCQFontBar
 * \brief QToolBar for font, fontsize and bold/italic selection.
 *
 * The toolbar is designed to change the appearance of a table displayed in a
 * UCQTableView. It allows the user to change the font, the fontsize and if
 * the letters are printed bold or/and italic. Every action emits a signal
 * that can be directly connected to a UCQTableView slot.
 *
 * \author Martin Burgemeister <Martin.Burgemeister@gmx.de>,
 *         Mathis Lindemann <MathisLindemann@gmx.net>
 * \version 1.0
 * \date 16 August 2010
 *
 * \see MainWindow
 */
#include <QSettings>

class UCQFontBar: public QToolBar
{

Q_OBJECT

public:
    UCQFontBar ( QWidget* );

    void enableActions ( bool );
    void initFont();
    QFont getFont();

private:
    /**
     * \brief Action for bold selection.
     */
    QAction* actionBold_;
    /**
     * \brief Action for italic selection.
     */
    QAction* actionItalic_;
    /**
     * \brief Combo for font selection.
     */
    QFontComboBox* fontComboBox_;
    /**
     * \brief Combo for fontsize selection.
     */
    QComboBox* sizeComboBox_;

public slots:
    void selectFont( const QFont& );

protected slots:
	void saveCurrentFont( const QFont& );

signals:
    /**
     * \brief Emitted when a different font is selected.
     *
     * \param font The font that got selected.
     */
    void currentFontChanged ( const QFont& font );
    /**
     * \brief Emitted when a different fontsize is selected.
     *
     * \param size The size that was selected.
     */
    void currentSizeChanged ( const QString& size );
    /**
     * \brief Emitted when bold is (de)selected.
     *
     * \param bold If true, bold is activated.
     */
    void bold_toggled ( bool bold );
    /**
     * \brief Emitted when italic is (de)selected.
     *
     * \param italic If true, bold is activated.
     */
    void italic_toggled ( bool italic );
};

#endif /* UCQFONTBAR_H_ */
