/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann           *
 *                                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef LUAWRAPPER_H_
#define LUAWRAPPER_H_

extern "C" {
#include <lua.h>
#include <lualib.h>
#include <lauxlib.h>
}
#include "controller/Controller.h"
#include <QString>

/**
 * \class LuaWrapper
 * \brief Base class for all wrapper classes.
 *
 * This class is the base for all wrapper classes. The
 * class has the function isNull() and isController(). They
 * are used by the class Luna.
 *
 * \author Martin Burgemeister <Martin.Burgemeister@gmx.de>,
 *         Mathis Lindemann <MathisLindemann@gmx.net>
 * \version 1.0
 * \date 28 August 2010
 * \see Luna
 */
class LuaWrapper
{
public:
    LuaWrapper ( lua_State*, QString );
    virtual ~LuaWrapper ();
    bool isNull ();
    bool isController ();

    void setWrapperName ( QString );
    QString getWrapperName () const;

private:
    /**
     * Object of the controller.
     */
    Controller* objectController_;

    /**
     * \brief Wrapper for controller
     */
    QString wrapperName_;
};

#endif /* LUAWRAPPER_H_ */
