/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann		   *
 *      																   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "UCQExecuteLuaThread.h"
/**
 * \brief Constructor sets the lua controller and the execution mode.
 */
UCQExecuteLuaThread::UCQExecuteLuaThread(LuaController * lua, ExecutionMode em) {
	executionMode_ = em;
	lua_ = lua;

}

/**
 * \brief Starts the thread with the given string.
 */
void UCQExecuteLuaThread::execute(QString execute){
	execute_ = execute;
	start();
}

/**
 * \brief Is called when the thread is started.
 */
void UCQExecuteLuaThread::run() {
	emit running(true);
	switch (executionMode_) {
	case EXECUTE_FILE:
		lua_->doFile(execute_);
		break;
	case EXECUTE_STRING:
		lua_->doString(execute_);
		break;
	}
	emit running(false);
}

/**
 * \brief Sets the execution mode
 *
 * File execution or string execution.
 *
 * \param exeMode Execution mode
 */
void UCQExecuteLuaThread::setexecutionMode(ExecutionMode exeMode){
	executionMode_ = exeMode;
}

/**
 * \brief Sets the LuaController.
 *
 * \param l The LuaController.
 */
void UCQExecuteLuaThread::setLuaController ( LuaController* l )
{
    lua_ = l;
}
